@@ -14,6 +14,8 @@
 
 G_BEGIN_DECLS
 
+#ifndef BONOBO_DISABLE_DEPRECATED
+
 /* For backwards compatibility */
 #define BonoboStream BonoboObject
 #define BONOBO_STREAM(o)       ((BonoboStream *)(o))
@@ -23,6 +25,8 @@ G_BEGIN_DECLS
 #define BONOBO_STORAGE(o)          ((BonoboStorage *)(o))
 #define BONOBO_STORAGE_CLASS(k)    ((BonoboObjectClass *)(k))
 
+#endif /* BONOBO_DISABLE_DEPRECATED */
+
 
 /* The 1 useful impl. in here */
 void bonobo_storage_copy_to (Bonobo_Storage     src,
